@@ -11,7 +11,7 @@ library("wrapr")
 
 ## ----nofn----------------------------------------------------------------
 5 %.>% sin
-5 %.>% base::sin # new for wrapr 1.3.1
+5 %.>% base::sin 
 
 ## ----sinfn---------------------------------------------------------------
 function_reference <- list(f = sin)
